Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1724)

Unified Diff: content/common/speech_recognition_messages.h

Issue 636863003: Make SpeechRecognition per RenderFrame instead of per RenderView. Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: review comments Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/common/frame_messages.h ('k') | content/public/browser/speech_recognition_manager.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/common/speech_recognition_messages.h
diff --git a/content/common/speech_recognition_messages.h b/content/common/speech_recognition_messages.h
index 7ad6aee1363237e8f02d66cf34f5856770a944c2..3e6900cb117cb8a459da6da22101fa41c4555fc4 100644
--- a/content/common/speech_recognition_messages.h
+++ b/content/common/speech_recognition_messages.h
@@ -49,8 +49,8 @@ IPC_STRUCT_TRAITS_END()
// Used to start a speech recognition session.
IPC_STRUCT_BEGIN(SpeechRecognitionHostMsg_StartRequest_Params)
- // The render view requesting speech recognition.
- IPC_STRUCT_MEMBER(int, render_view_id)
+ // The render frame requesting speech recognition.
+ IPC_STRUCT_MEMBER(int, render_frame_id)
// Unique ID associated with the JS object making the calls.
IPC_STRUCT_MEMBER(int, request_id)
// Language to use for speech recognition.
@@ -74,26 +74,25 @@ IPC_STRUCT_END()
IPC_MESSAGE_CONTROL1(SpeechRecognitionHostMsg_StartRequest,
SpeechRecognitionHostMsg_StartRequest_Params)
// Requests the speech recognition service to abort speech recognition on
// behalf of the given |render_view_id| and |request_id|. If there are no
// sessions associated with the |request_id| in the render view, this call
// does nothing.
IPC_MESSAGE_CONTROL2(SpeechRecognitionHostMsg_AbortRequest,
- int /* render_view_id */,
+ int /* render_frame_id */,
int /* request_id */)
// Requests the speech recognition service to abort all speech recognitions on
// behalf of the given |render_view_id|. If speech recognition is not happening
// or is happening on behalf of some other render view, this call does nothing.
IPC_MESSAGE_CONTROL1(SpeechRecognitionHostMsg_AbortAllRequests,
- int /* render_view_id */)
+ int /* render_frame_id */)
-// Requests the speech recognition service to stop audio capture on behalf of
-// the given |render_view_id|. Any audio recorded so far will be fed to the
-// speech recognizer. If speech recognition is not happening nor or is
-// happening on behalf of some other render view, this call does nothing.
+// Requests the speech recognition service to stop audio capture associated with
+// |request_id|. Any audio recorded so far will be fed to the speech recognizer.
+// If there are no sessions associated with |request_id|, this call does
+// nothing.
IPC_MESSAGE_CONTROL2(SpeechRecognitionHostMsg_StopCaptureRequest,
- int /* render_view_id */,
+ int /* render_frame_id */,
int /* request_id */)
// Browser -> Renderer messages.
« no previous file with comments | « content/common/frame_messages.h ('k') | content/public/browser/speech_recognition_manager.h » ('j') | no next file with comments »
@@ -74,26 +74,25 @@ IPC_STRUCT_END()
IPC_MESSAGE_CONTROL1(SpeechRecognitionHostMsg_StartRequest,
SpeechRecognitionHostMsg_StartRequest_Params)
-// Requests the speech recognition service to abort speech recognition on
-// behalf of the given |render_view_id| and |request_id|. If there are no
-// sessions associated with the |request_id| in the render view, this call
-// does nothing.
+// Requests the speech recognition service to abort speech recognition
+// associated with |request_id|. If there are no sessions associated with the
+// |request_id| in the render frame, this call does nothing.
IPC_MESSAGE_CONTROL2(SpeechRecognitionHostMsg_AbortRequest,
@@ -74,26 +74,25 @@ IPC_STRUCT_END()
int /* request_id */)
-// Requests the speech recognition service to abort all speech recognitions on
-// behalf of the given |render_view_id|. If speech recognition is not happening
-// or is happening on behalf of some other render view, this call does nothing.
+// Requests the speech recognition service to abort all speech recognitions
+// running for the frame. If speech recognition is not happening for that frame,
+// this call does nothing.
IPC_MESSAGE_CONTROL1(SpeechRecognitionHostMsg_AbortAllRequests,

Powered by Google App Engine
This is Rietveld 408576698